from setuptools import setup
setup(
    name='cnlunar',
    version='0.1.6',
    packages=['cnlunar'],
    url='https://github.com/OPN48/cnLunar',
    author='cuba3',
    author_email='cuba3@163.com',
    long_description=open('README.rst', encoding='utf-8').read(),
)
